@@ -51,6 +51,10 @@ def _get_lyrics(page_title):
 		
 	content = revisions["revisions"][0]["*"]
 	
+	if content.startswith("#Redirect"):
+		n_title = content[content.find("[[") + 2:content.rfind("]]")]
+		return _get_lyrics(n_title)
+	
 	if "<lyrics>" in content:
 		return content[content.find("<lyrics>") + len("<lyrics>") : content.find("</lyrics>")].strip()
 	elif "<lyric>" in content:
@@ -62,3 +66,5 @@ def get_lyrics(artist, title):
 	"""
 	
 	return _get_lyrics("%s:%s" %(artist.title(), title.title()))
+
+print get_lyrics("the shins", "sealegs")
